@@ -1,3 +1,7 @@
+# Copyright FuseSoC contributors
+# Licensed under the 2-Clause BSD License, see LICENSE for details.
+# SPDX-License-Identifier: BSD-2-Clause
+
 #!/usr/bin/env python
 import argparse
 import os
@@ -20,7 +24,7 @@ from fusesoc.librarymanager import Library
 from fusesoc.edalizer import Edalizer
 from edalize import get_edatool
 from fusesoc.vlnv import Vlnv
-from fusesoc.utils import Launcher, setup_logging
+from fusesoc.utils import Launcher, setup_logging, yaml_fread
 
 import logging
 
@@ -408,30 +412,24 @@ def run_backend(
     if not os.path.exists(eda_api_file):
         do_configure = True
 
+    backend_class = get_edatool(tool)
+
+    edalizer = Edalizer(
+        toplevel=core.name,
+        flags=flags,
+        core_manager=cm,
+        cache_root=cm.config.cache_root,
+        work_root=work_root,
+        export_root=export_root,
+        system_name=system_name,
+    )
+
     if do_configure:
         try:
-            cores = cm.get_depends(core.name, flags)
-        except DependencyError as e:
-            logger.error(
-                e.msg + "\nFailed to resolve dependencies for {}".format(system)
-            )
-            exit(1)
-        except SyntaxError as e:
-            logger.error(e.msg)
-            exit(1)
-        try:
-            edalizer = Edalizer(
-                core.name,
-                flags,
-                cores,
-                cache_root=cm.config.cache_root,
-                work_root=work_root,
-                export_root=export_root,
-                system_name=system_name,
-            )
-
-            backend_class = get_edatool(tool)
-            edalizer.parse_args(backend_class, backendargs)
+            edalizer.run()
+            edam = edalizer.edalize
+            parsed_args = edalizer.parse_args(backend_class, backendargs, edam)
+            edalizer.add_parsed_args(backend_class, parsed_args)
 
         except SyntaxError as e:
             logger.error(e.msg)
@@ -440,16 +438,13 @@ def run_backend(
             logger.error("Setup failed : {}".format(str(e)))
             exit(1)
         edalizer.to_yaml(eda_api_file)
+    else:
+        edam = yaml_fread(eda_api_file)
+        parsed_args = edalizer.parse_args(backend_class, backendargs, edam)
 
     # Frontend/backend separation
 
     try:
-        if do_configure:
-            edam = edalizer.edalize
-        else:
-            import yaml
-
-            edam = yaml.safe_load(open(eda_api_file))
         backend = get_edatool(tool)(edam=edam, work_root=work_root)
 
     except ImportError:
@@ -480,7 +475,7 @@ def run_backend(
 
     if do_run:
         try:
-            backend.run(backendargs)
+            backend.run(parsed_args)
         except RuntimeError as e:
             logger.error("Failed to run {} : {}".format(str(core.name), str(e)))
             exit(1)
@@ -548,7 +543,7 @@ def init_coremanager(config, args_cores_root):
     for library in config.libraries + args_libs:
         try:
             cm.add_library(library)
-        except (RuntimeError, IOError) as e:
+        except (RuntimeError, OSError) as e:
             _s = "Failed to register library '{}'"
             logger.warning(_s.format(str(e)))
 
